.. :changelog:

History
-------

0.2.0 (2020-10-20)
++++++++++++++++++

* Added test (and associated code fixes) of round-trip import and
  serialisation of EAD3 XML.


0.1.2 (2020-10-16)
++++++++++++++++++

* Added XSD files to MANIFEST.in, so that the EAD3 XSD is included in
  the package.


0.1.1 (2020-10-13)
++++++++++++++++++

* Added dependency on lxml.


0.1.0 (2020-10-09)
++++++++++++++++++

* First release on PyPI.
